Properties Methods Events Direct Link

# Class Ext.calendar.EventMappings

Package: | Ext.calendar
Defined In: | EventRecord.js
Class: | EventMappings
Extends: | Object

A simple object that provides the field definitions for EventRecords so that they can be easily overridden.

## Public Properties

This class has no public properties.

## Public Methods

This class has no public methods.

## Public Events

This class has no public events.